==> eccodes-2.23.0-h36aa8e7_3.tar.bz2: Library/include/eccodes_ecbuild_config.h <==
/*
 * (C) Copyright 2011- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

#ifndef eccodes_ecbuild_config_h
#define eccodes_ecbuild_config_h

/* ecbuild info */

#ifndef ECBUILD_VERSION_STR
#define ECBUILD_VERSION_STR "3.6.3"
#endif
#ifndef ECBUILD_VERSION
#define ECBUILD_VERSION "3.6.3"
#endif
#ifndef ECBUILD_MACROS_DIR
#define ECBUILD_MACROS_DIR  "D:/bld/eccodes_1634328339120/work/cmake"
#endif

/* config info */

#define ECCODES_OS_NAME          "Windows-10.0.14393"
#define ECCODES_OS_BITS          64
#define ECCODES_OS_BITS_STR      "64"
#define ECCODES_OS_STR           "windows.64"
#define ECCODES_OS_VERSION       "10.0.14393"
#define ECCODES_SYS_PROCESSOR    "AMD64"

#define ECCODES_BUILD_TIMESTAMP  ""
#define ECCODES_BUILD_TYPE       "Release"

#define ECCODES_C_COMPILER_ID      "MSVC"
#define ECCODES_C_COMPILER_VERSION "19.16.27045.0"

#define ECCODES_CXX_COMPILER_ID      ""
#define ECCODES_CXX_COMPILER_VERSION ""

#define ECCODES_C_COMPILER       "C:/Program Files (x86)/Microsoft Visual Studio/2017/Enterprise/VC/Tools/MSVC/14.16.27023/bin/Hostx64/x64/cl.exe"
#define ECCODES_C_FLAGS          "/DWIN32 /D_WINDOWS /W3 /D_CRT_SECURE_NO_WARNINGS /D_CRT_NONSTDC_NO_DEPRECATE /wd4267 /MD /O2 /Ob2 /DNDEBUG"

#define ECCODES_CXX_COMPILER     ""
#define ECCODES_CXX_FLAGS        ""

/* Needed for finding per package config files */

#define ECCODES_INSTALL_DIR       "D:/bld/eccodes_1634328339120/_h_env/Library"
#define ECCODES_INSTALL_BIN_DIR   "D:/bld/eccodes_1634328339120/_h_env/Library/bin"
#define ECCODES_INSTALL_LIB_DIR   "D:/bld/eccodes_1634328339120/_h_env/Library/lib"
#define ECCODES_INSTALL_DATA_DIR  "D:/bld/eccodes_1634328339120/_h_env/Library/share/eccodes"

#define ECCODES_DEVELOPER_SRC_DIR "D:/bld/eccodes_1634328339120/work"
#define ECCODES_DEVELOPER_BIN_DIR "D:/bld/eccodes_1634328339120/work/build"

/* Fortran support */

#if 0

#define ECCODES_Fortran_COMPILER_ID      ""
#define ECCODES_Fortran_COMPILER_VERSION ""

#define ECCODES_Fortran_COMPILER ""
#define ECCODES_Fortran_FLAGS    ""

#endif

#endif /* eccodes_ecbuild_config_h */

==> eccodes-2.24.0-h36aa8e7_0.tar.bz2: Library/include/eccodes_ecbuild_config.h <==
/*
 * (C) Copyright 2011- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */

#ifndef ECCODES_ecbuild_config_h
#define ECCODES_ecbuild_config_h

/* ecbuild info */

#ifndef ECBUILD_VERSION_STR
#define ECBUILD_VERSION_STR "3.6.4"
#endif
#ifndef ECBUILD_VERSION
#define ECBUILD_VERSION "3.6.4"
#endif
#ifndef ECBUILD_MACROS_DIR
#define ECBUILD_MACROS_DIR  "D:/bld/eccodes_1638916851819/work/cmake"
#endif

/* config info */

#define ECCODES_OS_NAME          "Windows-10.0.14393"
#define ECCODES_OS_BITS          64
#define ECCODES_OS_BITS_STR      "64"
#define ECCODES_OS_STR           "windows.64"
#define ECCODES_OS_VERSION       "10.0.14393"
#define ECCODES_SYS_PROCESSOR    "AMD64"

#define ECCODES_BUILD_TIMESTAMP  ""
#define ECCODES_BUILD_TYPE       "Release"

#define ECCODES_C_COMPILER_ID      "MSVC"
#define ECCODES_C_COMPILER_VERSION "19.16.27045.0"

#define ECCODES_CXX_COMPILER_ID      ""
#define ECCODES_CXX_COMPILER_VERSION ""

#define ECCODES_C_COMPILER       "C:/Program Files (x86)/Microsoft Visual Studio/2017/Enterprise/VC/Tools/MSVC/14.16.27023/bin/Hostx64/x64/cl.exe"
#define ECCODES_C_FLAGS          "/DWIN32 /D_WINDOWS /W3 /D_CRT_SECURE_NO_WARNINGS /D_CRT_NONSTDC_NO_DEPRECATE /wd4267 /MD /O2 /Ob2 /DNDEBUG"

#define ECCODES_CXX_COMPILER     ""
#define ECCODES_CXX_FLAGS        ""

/* Needed for finding per package config files */

#define ECCODES_INSTALL_DIR       "D:/bld/eccodes_1638916851819/_h_env/Library"
#define ECCODES_INSTALL_BIN_DIR   "D:/bld/eccodes_1638916851819/_h_env/Library/bin"
#define ECCODES_INSTALL_LIB_DIR   "D:/bld/eccodes_1638916851819/_h_env/Library/lib"
#define ECCODES_INSTALL_DATA_DIR  "D:/bld/eccodes_1638916851819/_h_env/Library/share/eccodes"

#define ECCODES_DEVELOPER_SRC_DIR "D:/bld/eccodes_1638916851819/work"
#define ECCODES_DEVELOPER_BIN_DIR "D:/bld/eccodes_1638916851819/work/build"

/* Fortran support */

#if 0

#define ECCODES_Fortran_COMPILER_ID      ""
#define ECCODES_Fortran_COMPILER_VERSION ""

#define ECCODES_Fortran_COMPILER ""
#define ECCODES_Fortran_FLAGS    ""

#endif

#endif /* ECCODES_ecbuild_config_h */
